@@ -233,7 +233,7 @@ static int k3_r5f_prepare(struct udevice *dev)
 
 	dev_dbg(dev, "%s\n", __func__);
 
-	if (cluster->mode == CLUSTER_MODE_LOCKSTEP)
+	if ((cluster->mode == CLUSTER_MODE_LOCKSTEP) || (cluster->mode == CLUSTER_MODE_SINGLECPU))
 		ret = k3_r5f_lockstep_release(cluster);
 	else
 		ret = k3_r5f_split_release(core);
@@ -269,6 +269,13 @@ static int k3_r5f_core_sanity_check(struct k3_r5f_core *core)
 		return -EINVAL;
 	}
 
+	if (cluster->mode == CLUSTER_MODE_SINGLECPU && !is_primary_core(core)) {
+		dev_err(core->dev,
+			"Invalid op: Trying to start secondary core %d in single CPU mode\n",
+			core->tsp.proc_id);
+		return -EINVAL;
+	}
+
 	if (cluster->mode == CLUSTER_MODE_SPLIT && !is_primary_core(core)) {
 		if (!core->cluster->cores[0]->in_use) {
 			dev_err(core->dev,
@@ -441,7 +448,7 @@ proc_release:
 
 static int k3_r5f_split_reset(struct k3_r5f_core *core)
 {
-	int ret;
+	int ret = 0;
 
 	dev_dbg(core->dev, "%s\n", __func__);
 
@@ -476,7 +483,7 @@ static int k3_r5f_unprepare(struct udevice *dev)
 {
 	struct k3_r5f_core *core = dev_get_priv(dev);
 	struct k3_r5f_cluster *cluster = core->cluster;
-	int ret;
+	int ret = 0;
 
 	dev_dbg(dev, "%s\n", __func__);
 
@@ -527,7 +534,7 @@ proc_release:
 	return ret;
 }
 
-static void *k3_r5f_da_to_va(struct udevice *dev, ulong da, ulong size)
+static void *k3_r5f_da_to_va(struct udevice *dev, ulong da, ulong size, bool *is_iomem)
 {
 	struct k3_r5f_core *core = dev_get_priv(dev);
 	void __iomem *va = NULL;
@@ -768,7 +775,7 @@ static void k3_r5f_core_adjust_tcm_sizes(struct k3_r5f_core *core)
 {
 	struct k3_r5f_cluster *cluster = core->cluster;
 
-	if (cluster->mode == CLUSTER_MODE_LOCKSTEP)
+	if ((cluster->mode == CLUSTER_MODE_LOCKSTEP) || (cluster->mode == CLUSTER_MODE_SINGLECPU))
 		return;
 
 	if (!core->ipdata->tcm_is_double)
